@@ -33,6 +33,8 @@ class IndexStructType(str, Enum):
         OPENSEARCH ("opensearch"): Opensearch Vector Store Index.
             See :ref:`Ref-Indices-VectorStore`
             for more information on the Opensearch vector store index.
+        CHATGPT_RETRIEVAL_PLUGIN ("chatgpt_retrieval_plugin"): ChatGPT
+            retrieval plugin index.
         SQL ("SQL"): SQL Structured Store Index.
             See :ref:`Ref-Indices-StructStore`
             for more information on the SQL vector store index.
@@ -58,6 +60,7 @@ class IndexStructType(str, Enum):
     CHROMA = "chroma"
     VECTOR_STORE = "vector_store"
     OPENSEARCH = "opensearch"
+    CHATGPT_RETRIEVAL_PLUGIN = "chatgpt_retrieval_plugin"
 
     # for SQL index
     SQL = "sql"
