@@ -31,6 +31,7 @@ class GPTVectorStoreIndex(BaseGPTIndex[IndexDict]):
     Args:
         text_qa_template (Optional[QuestionAnswerPrompt]): A Question-Answer Prompt
             (see :ref:`Prompt-Templates`).
+            NOTE: this is a deprecated field.
         embed_model (Optional[BaseEmbedding]): Embedding model to use for
             embedding similarity.
         vector_store (Optional[VectorStore]): Vector store to use for
@@ -260,6 +261,8 @@ class GPTVectorStoreIndex(BaseGPTIndex[IndexDict]):
 
     def _preprocess_query(self, mode: QueryMode, query_kwargs: Any) -> None:
         super()._preprocess_query(mode, query_kwargs)
+        if "text_qa_template" not in query_kwargs:
+            query_kwargs["text_qa_template"] = self.text_qa_template
         # NOTE: Pass along vector store instance to query objects
         # TODO: refactor this to be more explicit
         query_kwargs["vector_store"] = self._vector_store
