@@ -10,6 +10,7 @@ definition of a Document - the bare minimum is a `text` property.
 
 """
 
+from gpt_index.readers.chatgpt_plugin import ChatGPTRetrievalPluginReader
 from gpt_index.readers.chroma import ChromaReader
 from gpt_index.readers.discord_reader import DiscordReader
 from gpt_index.readers.elasticsearch import ElasticsearchReader
@@ -72,4 +73,5 @@ __all__ = [
     "MboxReader",
     "ElasticsearchReader",
     "SteamshipFileReader",
+    "ChatGPTRetrievalPluginReader",
 ]
