@@ -89,7 +89,7 @@ class MarkdownParser(BaseParser):
         self, filepath: Path, errors: str = "ignore"
     ) -> List[Tuple[Optional[str], str]]:
         """Parse file into tuples."""
-        with open(filepath, "r") as f:
+        with open(filepath, "r", encoding="utf-8") as f:
             content = f.read()
         if self._remove_hyperlinks:
             content = self.remove_hyperlinks(content)
