@@ -1,9 +1,12 @@
 """Test struct store indices."""
 
 import re
+import asyncio
 from typing import Any, Dict, List, Optional, Tuple
+from unittest.mock import patch
 
 import pytest
+
 from sqlalchemy import (
     Column,
     Integer,
@@ -23,9 +26,11 @@ from gpt_index.indices.struct_store.sql import (
     SQLContextContainerBuilder,
 )
 from gpt_index.langchain_helpers.sql_wrapper import SQLDatabase
+from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.readers.schema.base import Document
 from gpt_index.schema import BaseDocument
 from tests.mock_utils.mock_decorator import patch_common
+from tests.mock_utils.mock_predict import mock_llmpredictor_apredict
 from tests.mock_utils.mock_prompts import (
     MOCK_REFINE_PROMPT,
     MOCK_SCHEMA_EXTRACT_PROMPT,
@@ -355,6 +360,50 @@ def test_sql_index_query(
     assert response.response == "[(2, 'bar'), (8, 'hello')]"
 
 
+@patch_common
+@patch.object(LLMPredictor, "apredict", side_effect=mock_llmpredictor_apredict)
+def test_sql_index_async_query(
+    _mock_async_predict: Any,
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    struct_kwargs: Tuple[Dict, Dict],
+) -> None:
+    """Test GPTSQLStructStoreIndex."""
+    index_kwargs, query_kwargs = struct_kwargs
+    docs = [Document(text="user_id:2,foo:bar"), Document(text="user_id:8,foo:hello")]
+    engine = create_engine("sqlite:///:memory:")
+    metadata_obj = MetaData(bind=engine)
+    table_name = "test_table"
+    # NOTE: table is created by tying to metadata_obj
+    Table(
+        table_name,
+        metadata_obj,
+        Column("user_id", Integer, primary_key=True),
+        Column("foo", String(16), nullable=False),
+    )
+    metadata_obj.create_all()
+    sql_database = SQLDatabase(engine)
+    # NOTE: we can use the default output parser for this
+    index = GPTSQLStructStoreIndex(
+        docs, sql_database=sql_database, table_name=table_name, **index_kwargs
+    )
+
+    # query the index with SQL
+    task = index.aquery(
+        "SELECT user_id, foo FROM test_table", mode="sql", **query_kwargs
+    )
+    response = asyncio.run(task)
+    assert response.response == "[(2, 'bar'), (8, 'hello')]"
+
+    # query the index with natural language
+    task = index.aquery("test_table:user_id,foo", mode="default", **query_kwargs)
+    response = asyncio.run(task)
+    assert response.response == "[(2, 'bar'), (8, 'hello')]"
+
+
 def test_default_output_parser() -> None:
     """Test default output parser."""
     test_str = "user_id:2\n" "foo:bar\n" ",,testing:testing2..\n" "number:123,456,789\n"
