@@ -12,6 +12,7 @@ from gpt_index.langchain_helpers.chain_wrapper import (
     LLMMetadata,
     LLMPredictor,
 )
+from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
 from gpt_index.readers.schema.base import Document
 from tests.mock_utils.mock_decorator import patch_common
 from tests.mock_utils.mock_predict import (
@@ -25,6 +26,9 @@ from tests.mock_utils.mock_prompts import (
     MOCK_SUMMARY_PROMPT,
     MOCK_TEXT_QA_PROMPT,
 )
+from tests.mock_utils.mock_text_splitter import (
+    mock_token_splitter_newline_with_overlaps,
+)
 
 
 @pytest.fixture
@@ -298,11 +302,24 @@ def test_insert(
     assert tree.index_struct.all_nodes[0].ref_doc_id == "new_doc_test"
 
 
+def _mock_tokenizer(text: str) -> int:
+    """Mock tokenizer that splits by spaces."""
+    return len(text.split(" "))
+
+
 @patch.object(LLMChain, "predict", side_effect=mock_llmchain_predict)
 @patch("gpt_index.llm_predictor.base.OpenAI")
 @patch.object(LLMPredictor, "get_llm_metadata", return_value=LLMMetadata())
 @patch.object(LLMChain, "__init__", return_value=None)
+@patch.object(
+    TokenTextSplitter,
+    "split_text_with_overlaps",
+    side_effect=mock_token_splitter_newline_with_overlaps,
+)
+@patch.object(LLMPredictor, "_count_tokens", side_effect=_mock_tokenizer)
 def test_build_and_count_tokens(
+    _mock_count_tokens: Any,
+    _mock_split_text: Any,
     _mock_init: Any,
     _mock_llm_metadata: Any,
     _mock_llmchain: Any,
@@ -312,12 +329,16 @@ def test_build_and_count_tokens(
 ) -> None:
     """Test build and count tokens."""
     index_kwargs, _ = struct_kwargs
-    # mock_prompts.MOCK_SUMMARY_PROMPT_TMPL adds a "\n" to the document text
-    # and the document is 23 tokens
-    document_token_count = 24
-    llmchain_mock_resp_token_count = 10
+    # First block is "Hello world.\nThis is a test.\n"
+    # Second block is "This is another test.\nThis is a test v2."
+    # first block is 5 tokens because
+    # last word of first line and first word of second line are joined
+    # second block is 8 tokens for similar reasons.
+    first_block_count = 5
+    second_block_count = 8
+    llmchain_mock_resp_token_count = 4
     tree = GPTTreeIndex(documents, **index_kwargs)
-    assert (
-        tree._llm_predictor.total_tokens_used
-        == document_token_count + llmchain_mock_resp_token_count
+    assert tree._llm_predictor.total_tokens_used == (
+        (first_block_count + llmchain_mock_resp_token_count)
+        + (second_block_count + llmchain_mock_resp_token_count)
     )
